@@ -2,7 +2,7 @@
  * File:	win.c
  * Purpose:	Implement top level windows.
  * Author:	Lars Wirzenius
- * Version:	"@(#)SeX:$Id: win.c,v 1.57 1996/12/22 20:06:12 liw Exp $"
+ * Version:	"@(#)SeX:$Id: win.c,v 1.58 1997/09/19 21:35:18 liw Exp $"
  */
 
 #include <assert.h>
@@ -826,7 +826,7 @@ void win_popdown_msg(struct win *win) {
  * Purpose: Update scrollbar visually.
  */
 void win_set_scrollbar(struct win *win) {
-	float top, shown;
+	union { float f; XtArgVal dummy; } top, shown;
 	Arg arg[2];
 	XtArgVal *dummy[2];
 	Sbuf *buf;
@@ -843,11 +843,11 @@ void win_set_scrollbar(struct win *win) {
 	if (rows > total - topline)
 		rows = total - topline;
 	if (total > 0) {
-		top = (float) topline / total;
-		shown = (float) rows / total;
+		top.f = (float) topline / total;
+		shown.f = (float) rows / total;
 	} else {
-		top = 0.0;
-		shown = 1.0;
+		top.f = 0.0;
+		shown.f = 1.0;
 	}
 
 	XtSetArg(arg[0], XtNtopOfThumb, *dummy[0]);
@@ -860,11 +860,11 @@ void win_set_scrollbar(struct win *win) {
 		cols = total - leftcol;
 
 	if (total > 0) {
-		top = (float) leftcol / total;
-		shown = (float) cols / total;
+		top.f = (float) leftcol / total;
+		shown.f = (float) cols / total;
 	} else {
-		top = 0.0;
-		shown = 1.0;
+		top.f = 0.0;
+		shown.f = 1.0;
 	}
 	
 	XtSetArg(arg[0], XtNtopOfThumb, *dummy[0]);
